``Covariance`` Module
=====================

.. autoclass:: kite.Covariance
    :members:

CovarianceConfig
--------------------

.. autoclass:: kite.covariance.CovarianceConfig
    :members:

Model assumptions
-----------------

.. autofunction:: kite.covariance.modelCovarianceExponential

.. autofunction:: kite.covariance.modelCovarianceExponentialCosine

.. autofunction:: kite.covariance.modelPowerspec
